@@ -152,7 +152,7 @@ char * getline(char * buffer){
   if(*pnt != '.' && *pnt != 'L' && *pnt != '_' && *pnt != '#' &&
      *pnt != '/') {
     pnt2 = pnt;
-    while(isalpha(*pnt2) || isdigit(*pnt2) || *pnt2 == '$' || *pnt2 == '_')
+    while(isalnum(*pnt2) || *pnt2 == '.' || *pnt2 == '$' || *pnt2 == '_')
       pnt2++;
     /* If no label found, then this must be a machine instruction.  Add tab */
     if(*pnt2 != ':')  *pnt1++ = '\t';
@@ -324,8 +324,10 @@ int main(int argc, char **argv)
       strcat(filedir, "/");
    }
 
+#if 0
   if (filedir[0] != '/' && filedir[0] != '.')
-    fprintf(stderr,"Warning - non-absolute pathname specified in JUMP_DIR\n");\
+    fprintf(stderr,"Warning - non-absolute pathname specified in JUMP_DIR\n");
+#endif
 
   libname = getenv("JUMP_LIB");
   if (!libname)
