@@ -99,7 +99,7 @@ void mkcompat_usage (char name[])
      die (" %s\n","-L/usr/X386/lib -- -lXaw");
 }
 
-void main (int argc, char **argv)
+int main (int argc, char **argv)
 {
      FILE *stub=NULL, *jumpvars=NULL, *jumpfuncs=NULL;
      char tmp[MAX_LINE_LEN], found_dependencies = FALSE,
@@ -169,7 +169,7 @@ void main (int argc, char **argv)
 	    }
 	  }
       }
-     if (extract_only) return;
+     if (extract_only) return 0;
 
      if (jump_read) xfree(jump_read);
      for (; optind < argc; optind++) {
@@ -322,6 +322,7 @@ void main (int argc, char **argv)
 	if (!progname("libinfo")) exit(1);
      }
 	if (jump_write) xfree(jump_write);
+     exit (0);
 }
 
 void jump_vars (FILE * jumpvars, FILE * stub)
